summaryrefslogtreecommitdiffstats
path: root/filters/kword/rtf/import/rtfimport.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:12:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:12:30 -0600
commit11191ef0b9908604d1d7aaca382b011ef22c454c (patch)
treed38f0ccd8bfcc9756f5cfc42fb2ad1dad351e6aa /filters/kword/rtf/import/rtfimport.cpp
parentc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (diff)
downloadkoffice-11191ef0b9908604d1d7aaca382b011ef22c454c.tar.gz
koffice-11191ef0b9908604d1d7aaca382b011ef22c454c.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'filters/kword/rtf/import/rtfimport.cpp')
-rw-r--r--filters/kword/rtf/import/rtfimport.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/filters/kword/rtf/import/rtfimport.cpp b/filters/kword/rtf/import/rtfimport.cpp
index 94fad6970..5bfadbcbb 100644
--- a/filters/kword/rtf/import/rtfimport.cpp
+++ b/filters/kword/rtf/import/rtfimport.cpp
@@ -309,7 +309,7 @@ RTFImport::RTFImport( KoFilter *, const char *, const TQStringList& )
fnnum=0;
}
-KoFilter::ConversiontqStatus RTFImport::convert( const TQCString& from, const TQCString& to )
+KoFilter::ConversionStatus RTFImport::convert( const TQCString& from, const TQCString& to )
{
// This filter only supports RTF to KWord conversion
if ((from != "text/rtf") || (to != "application/x-kword"))
@@ -911,7 +911,7 @@ void RTFImport::setEnumProperty( RTFProperty *property )
void RTFImport::setFontStyleHint( RTFProperty* property )
{
- font.tqstyleHint = TQFont::StyleHint( property->value );
+ font.styleHint = TQFont::StyleHint( property->value );
}
void RTFImport::setPictureType( RTFProperty* property )
@@ -1321,7 +1321,7 @@ void RTFImport::parseFontTable( RTFProperty * )
if (token.type == RTFTokenizer::OpenGroup)
{
font.name = TQString();
- font.tqstyleHint = TQFont::AnyStyle;
+ font.styleHint = TQFont::AnyStyle;
font.fixedPitch = 0;
}
else if (token.type == RTFTokenizer::PlainText)
@@ -1344,7 +1344,7 @@ void RTFImport::parseFontTable( RTFProperty * )
// Use TQt to look up the closest matching installed font
TQFont qFont( font.name );
qFont.setFixedPitch( (font.fixedPitch == 1) );
- qFont.setStyleHint( font.tqstyleHint );
+ qFont.setStyleHint( font.styleHint );
for(;!qFont.exactMatch();)
{
int space=font.name.findRev(' ', font.name.length());
@@ -1362,7 +1362,7 @@ void RTFImport::parseFontTable( RTFProperty * )
else
fontTable.insert( state.format.font, newFontName );
font.name.truncate( 0 );
- font.tqstyleHint = TQFont::AnyStyle;
+ font.styleHint = TQFont::AnyStyle;
font.fixedPitch = 0;
}
}
@@ -1538,8 +1538,8 @@ void RTFImport::parsePicture( RTFProperty * )
// Add anchor to rich text destination
addAnchor( frameName );
- // It is safe, as we call tqcurrentDateTime only once for each picture
- const TQDateTime dt(TQDateTime::tqcurrentDateTime());
+ // It is safe, as we call currentDateTime only once for each picture
+ const TQDateTime dt(TQDateTime::currentDateTime());
// Add pixmap or clipart (key)
pictures.addKey( dt, idStr, pictName );
@@ -1614,7 +1614,7 @@ void RTFImport::addImportedPicture( const TQString& rawFileName )
// Add anchor to rich text destination
addAnchor( frameName );
// It is safe, as we call tqcurrentDateTime only once for each picture
const TQDateTime dt( pic.getKey().lastModified() );
// Add picture key
@@ -1614,7 +1614,7 @@ void RTFImport::addImportedPicture( const TQString& rawFileName )
// Add anchor to rich text destination
addAnchor( frameName );
- // It is safe, as we call tqcurrentDateTime only once for each picture
+ // It is safe, as we call currentDateTime only once for each picture
const TQDateTime dt( pic.getKey().lastModified() );
// Add picture key